@@ -258,6 +258,8 @@ bool parse_option(struct tofi *tofi, const char *filename, size_t lineno, const
 		tofi->window.entry.outline_color = parse_color(filename, lineno, value, &err);
 	} else if (strcasecmp(option, "prompt-text") == 0) {
 		snprintf(tofi->window.entry.prompt_text, N_ELEM(tofi->window.entry.prompt_text), "%s", value);
+	} else if (strcasecmp(option, "prompt-padding") == 0) {
+		tofi->window.entry.prompt_padding = parse_uint32(filename, lineno, value, &err);
 	} else if (strcasecmp(option, "min-input-width") == 0) {
 		tofi->window.entry.input_width = parse_uint32(filename, lineno, value, &err);
 	} else if (strcasecmp(option, "result-spacing") == 0) {
@@ -324,6 +326,8 @@ bool parse_option(struct tofi *tofi, const char *filename, size_t lineno, const
 		tofi->use_history = parse_bool(filename, lineno, value, &err);
 	} else if (strcasecmp(option, "fuzzy-match") == 0) {
 		tofi->fuzzy_match = parse_bool(filename, lineno, value, &err);
+	} else if (strcasecmp(option, "require-match") == 0) {
+		tofi->require_match = parse_bool(filename, lineno, value, &err);
 	} else if (strcasecmp(option, "drun-launch") == 0) {
 		tofi->drun_launch = parse_bool(filename, lineno, value, &err);
 	} else if (strcasecmp(option, "drun-print-exec") == 0) {
@@ -365,17 +369,11 @@ void config_fixup_values(struct tofi *tofi)
 {
 	uint32_t scale = tofi->window.scale;
 
-	/*
-	 * Scale fonts to the correct size.
-	 *
-	 * TODO: In the next release (0.6.0), this should be moved within
-	 * the use_scale conditional.
-	 */
-	tofi->window.entry.font_size *= scale;
-
 	if (tofi->use_scale) {
 		struct entry *entry = &tofi->window.entry;
 
+		tofi->window.entry.font_size *= scale;
+		entry->prompt_padding *= scale;
 		entry->corner_radius *= scale;
 		entry->selection_background_padding *= scale;
 		entry->result_spacing *= scale;
