@@ -158,7 +158,7 @@ static void handle_keypress(struct tofi *tofi, xkb_keycode_t keycode)
 			sizeof(buf));
 	wchar_t ch;
 	mbtowc(&ch, buf, sizeof(buf));
-	if (len > 0 && iswprint(ch) && (entry->drun || !iswblank(ch))) {
+	if (len > 0 && iswprint(ch)) {
 		if (entry->input_length < N_ELEM(entry->input) - 1) {
 			entry->input[entry->input_length] = ch;
 			entry->input_length++;
@@ -784,6 +784,7 @@ static void usage()
 "      --border-color <color>           Color of the border.\n"
 "      --text-color <color>             Color of text.\n"
 "      --prompt-text <string>           Prompt text.\n"
+"      --prompt-padding <px>            Padding between prompt and input.\n"
 "      --num-results <n>                Maximum number of results to display.\n"
 "      --selection-color <color>        Color of selected result.\n"
 "      --selection-match-color <color>  Color of the matching portion of the\n"
@@ -811,6 +812,7 @@ static void usage()
 "      --horizontal <true|false>        List results horizontally.\n"
 "      --history <true|false>           Sort results by number of usages.\n"
 "      --fuzzy-match <true|false>       Use fuzzy matching for searching.\n"
+"      --require-match <true|false>     Require a match for selection.\n"
 "      --drun-launch <true|false>       Launch apps directly in drun mode.\n"
 "      --drun-print-exec <true|false>   Print a command line in drun mode.\n"
 "                                       This is now always the case,\n"
@@ -839,6 +841,7 @@ const struct option long_options[] = {
 	{"outline-width", required_argument, NULL, 0},
 	{"outline-color", required_argument, NULL, 0},
 	{"prompt-text", required_argument, NULL, 0},
+	{"prompt-padding", required_argument, NULL, 0},
 	{"result-spacing", required_argument, NULL, 0},
 	{"min-input-width", required_argument, NULL, 0},
 	{"border-width", required_argument, NULL, 0},
@@ -858,6 +861,7 @@ const struct option long_options[] = {
 	{"hide-cursor", required_argument, NULL, 0},
 	{"history", required_argument, NULL, 0},
 	{"fuzzy-match", required_argument, NULL, 0},
+	{"require-match", required_argument, NULL, 0},
 	{"drun-launch", required_argument, NULL, 0},
 	{"drun-print-exec", required_argument, NULL, 0},
 	{"hint-font", required_argument, NULL, 0},
@@ -933,11 +937,22 @@ static void parse_args(struct tofi *tofi, int argc, char *argv[])
 	}
 }
 
-static void do_submit(struct tofi *tofi)
+static bool do_submit(struct tofi *tofi)
 {
 	struct entry *entry = &tofi->window.entry;
 	uint32_t selection = entry->selection + entry->first_result;
 	char *res = entry->results.buf[selection].string;
+
+	if (tofi->window.entry.results.count == 0) {
+		/* Always require a match in drun mode. */
+		if (tofi->require_match || entry->drun) {
+			return false;
+		} else {
+			printf("%ls\n", entry->input);
+			return true;
+		}
+	}
+
 	if (entry->drun) {
 		/*
 		 * TODO: This is ugly. The list of apps needs to be sorted
@@ -948,7 +963,7 @@ static void do_submit(struct tofi *tofi)
 		struct desktop_entry *app = desktop_vec_find(&entry->apps, res);
 		if (app == NULL) {
 			log_error("Couldn't find application file! This shouldn't happen.\n");
-			return;
+			return false;
 		} else {
 			res = app->path;
 		}
@@ -966,6 +981,7 @@ static void do_submit(struct tofi *tofi)
 				entry->results.buf[selection].string);
 		history_save(&entry->history, entry->drun);
 	}
+	return true;
 }
 
 int main(int argc, char *argv[])
@@ -1007,6 +1023,8 @@ int main(int argc, char *argv[])
 			| ZWLR_LAYER_SURFACE_V1_ANCHOR_LEFT
 			| ZWLR_LAYER_SURFACE_V1_ANCHOR_RIGHT,
 		.use_history = true,
+		.require_match = true,
+		.use_scale = true,
 	};
 	wl_list_init(&tofi.output_list);
 
@@ -1432,8 +1450,7 @@ int main(int argc, char *argv[])
 		}
 		if (tofi.submit) {
 			tofi.submit = false;
-			if (tofi.window.entry.results.count > 0) {
-				do_submit(&tofi);
+			if (do_submit(&tofi)) {
 				break;
 			}
 		}
